{******************************************************************************}
{          This unit is part of the Delphifreeware component package.          }
{                                                                              }
{ Filename           : DFWGlobes.pas                                           }
{ Short description  :                                                         }
{ Author             : Erol S. Uzuner                                          }
{ E-Mail             : sarcon@tzi.de                                           }
{ Internet           :                                                         }
{ Version            : 1.0                                                     }
{ Date last modified : 08.05.96                                                }
{ Delphi versions    :                                                         }
{                                                                              }
{                                                                              }
{ Add. Copyright     : Copyright (C) 1996-2000                                 }
{                                                                              }
{ Description        :                                                         }
{                                                                              }
{ Usage              :                                                         }
{                                                                              }
{ Revision history   :                                                         }
{                                                                              }
{ This unit contains the following                                             }
{ Components       :                                                           }
{ Classes          :                                                           }
{ Types            :                                                           }
{ Constants        :                                                           }
{ Global variables :                                                           }
{ Global procedures:                                                           }
{ Global functions : MsgDlg, isEqualDate, IsDate, IsTime, IsDateTime, IsInt,   }
{                    IsFloat, IsAInt, IsAFloat                                 }
{                                                                              }
{******************************************************************************}
{                                                                              }
{  DFW and Delphifreeware   2000, Carsten Butzek E-Mail: cabutzek@muenster.de }
{                                                                              }
{  Delphifreeware or DFW is a free Delphi component collection.                }
{  If you wrote a component which should be integrated into the DFW please     }
{  contact me.                                                                 }
{                                                                              }
{  Updates of the DFW package are available at the DFW homepage:               }
{  http://www.delphifreeware.de                                                }
{                                                                              }
{******************************************************************************}
{ License agreement                                                            }
{                                                                              }
{  This unit is freeware.                                                      }
{                                                                              }
{  Please do not release modified versions of this source code.                }
{  If you've made any changes that you think should have been there,           }
{  feel free to submit them to me at cabutzek@muenster.de                      }
{                                                                              }
{                                                                              }
{  This software is provided 'as-is', without any express or                   }
{  implied warranty. In no event will the author be held                       }
{  liable for any damages arising from the use of this                         }
{  software.                                                                   }
{  Permission is granted to anyone to use this software for                    }
{  any purpose, including commercial applications, and to                      }
{  alter it and redistribute it freely, subject to the                         }
{  following restrictions:                                                     }
{  1. The origin of this software must not be misrepresented,                  }
{     you must not claim that you wrote the original software.                 }
{     If you use this software in a product, an acknowledgment                 }
{     in the product documentation would be appreciated but is                 }
{     not required.                                                            }
{  2. Altered source versions must be plainly marked as such,                  }
{     and must not be misrepresented as being the original                     }
{     software.                                                                }
{  3. This notice may not be removed or altered from any                       }
{     source distribution.                                                     }
{  4. You must credit the DFW team in  your software including a               }
{     link to the DFW homepage at http://www.delphifreeware.de.                }
{                                                                              }
{ End of license agreement                                                     }
{                                                                              }
{******************************************************************************}

{$I DFW.INC}

unit DFWGlobes;

interface

uses SysUtils, Dialogs, Forms, Controls, StdCtrls;

{$IFNDEF D2}
function MsgDlg(const Msg: string; AType: TMsgDlgType;
  AButtons: TMsgDlgButtons; DefBtn: TMsgDlgBtn; HelpCtx: Longint): Word;
{$ENDIF}

function isEqualDate(date1, date2 : TDateTime) : boolean;


function IsDate(const DateStr: String) : Boolean;
function IsTime(const TimeStr : String) : Boolean;
function IsDateTime(const DateStr: String) : Boolean;
function IsInt(const int: string; var i : Integer): Boolean;
function IsFloat(const Float: string; var e : Extended): Boolean;
function IsAInt(const int: string): Boolean;
function IsAFloat(const Float: string): Boolean;


implementation

(***********************************************************************
 *                                                                     *
 *  Name        :  MsgDlg                                              *
 *                                                                     *
 *  Beschreibung:  Ein MessageDialog bei dem man den Aktiven Button    *
 *			 whlen kann                                   *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)

{$IFNDEF D2}
function MsgDlg(const Msg: string; AType: TMsgDlgType;
  AButtons: TMsgDlgButtons; DefBtn: TMsgDlgBtn; HelpCtx: Longint): Word;

const BtnNames: array[TMsgDlgBtn] of string = (
    'Yes', 'No', 'OK', 'Cancel', 'Abort', 'Retry', 'Ignore', 'All', 'NoToAll',
    'YesToAll', 'Help');

var
  W: TForm;
  i : Integer;
  OldCursor : TCursor;
begin
  OldCursor := Screen.Cursor;
  Screen.Cursor := crDefault;

  W := CreateMessageDialog(Msg, AType, AButtons);
  try
    for i := 0 to W.ControlCount-1 do
       if W.Controls[i] Is TButton then
           with W.Controls[i] as TButton do
                if name = BtnNames[DefBtn] then
                begin
                   default := true;
                   W.activeControl := TButton(W.Controls[i]);
                end
                else
                    default := false;

    W.HelpContext := HelpCtx;
    W.ScaleBy(Screen.PixelsPerInch, 96);
    Result := W.ShowModal;
  finally
    W.Free;
    Screen.Cursor := OldCursor
  end;
end;
{$ENDIF}

(***********************************************************************
 *                                                                     *
 *  Name        :  isEqualDate                                         *
 *                                                                     *
 *  Beschreibung:   berprfen auf gleiches Datum		       *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)

function isEqualDate(date1, date2 : TDateTime) : boolean;
begin Result := DateTimeToTimeStamp(date1).Date = DateTimeToTimeStamp(date2).Date;
end;


(***********************************************************************
 *                                                                     *
 *  Name        :  IsDate                                              *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsDate(const DateStr: String) : Boolean;
begin
   Result := TRUE;
   try
      StrToDate(DateStr);
   except
//      on EConvertError do Result := FALSE;
        on Exception do Result := FALSE;
   end;
end;

(***********************************************************************
 *                                                                     *
 *  Name        :  IsTime                                              *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsTime(const TimeStr: String) : Boolean;
begin
   Result := TRUE;
   try
      StrToTime(TimeStr);
   except
//      on EConvertError do Result := FALSE;
        on Exception do Result := FALSE;
   end;
end;

(***********************************************************************
 *                                                                     *
 *  Name        :  IsInt                                               *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsInt(const int: string; var i : Integer): Boolean;
var E : Integer;
begin
  Val(int, i, E);
  Result := E = 0;
end;

function IsAInt(const int: string): Boolean;
var E, i : Integer;
begin
  Val(int, i, E);
  Result := E = 0;
end;

(***********************************************************************
 *                                                                     *
 *  Name        :  IsDate                                              *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsDateTime(const DateStr: String) : Boolean;
begin
   Result := TRUE;
   try
      StrToDateTime(DateStr);
   except
//      on EConvertError do Result := FALSE;
        on Exception do Result := FALSE;
   end;
end;


(***********************************************************************
 *                                                                     *
 *  Name        :  IsFloat                                             *
 *                                                                     *
 *  Beschreibung:                                                      *
 *                                                                     *
 *  Rueckgabe   :                                                      *
 *                                                                     *
 ***********************************************************************)
function IsFloat(const Float: string; var e : Extended): Boolean;
begin Result := TextToFloat(PChar(Float), e, fvExtended);
end;

function IsAFloat(const Float: string): Boolean;
var e : Extended;
begin Result := TextToFloat(PChar(Float), e, fvExtended);
end;



end.
