{******************************************************************************}
{          This unit is part of the Delphifreeware component package.          }
{                                                                              }
{ Filename           : DFWMRUfiles.pas                                         }
{ Short description  :                                                         }
{ Author             : Kambiz R. Khojasteh                                     }
{ E-Mail             : khojasteh@www.dci.co.ir                                 }
{ Internet           : http://www.crosswinds.net/~khojasteh/                   }
{ Version            : 1.0                                                     }
{ Date last modified : February 03, 2000                                       }
{ Delphi versions    : all delphi versions                                     }
{                                                                              }
{                                                                              }
{ Add. Copyright     :                                                         }
{                                                                              }
{ Description        :                                                         }
{                                                                              }
{ Usage              :                                                         }
{                                                                              }
{ Revision history   :                                                         }
{                                                                              }
{ This unit contains the following                                             }
{ Components       : TDFWMRUFiles                                              }
{ Classes          :                                                           }
{ Types            : TMRUClickEvent                                            }
{ Constants        :                                                           }
{ Global variables :                                                           }
{ Global procedures:                                                           }
{ Global functions :                                                           }
{                                                                              }
{******************************************************************************}
{                                                                              }
{  DFW and Delphifreeware   2000, Carsten Butzek E-Mail: cabutzek@muenster.de }
{                                                                              }
{  Delphifreeware or DFW is a free Delphi component collection.                }
{  If you wrote a component which should be integrated into the DFW please     }
{  contact me.                                                                 }
{                                                                              }
{  Updates of the DFW package are available at the DFW homepage:               }
{  http://www.delphifreeware.de                                                }
{                                                                              }
{******************************************************************************}
{ License agreement                                                            }
{                                                                              }
{  This unit is freeware.                                                      }
{                                                                              }
{  Please do not release modified versions of this source code.                }
{  If you've made any changes that you think should have been there,           }
{  feel free to submit them to me at cabutzek@muenster.de                      }
{                                                                              }
{                                                                              }
{  This software is provided 'as-is', without any express or                   }
{  implied warranty. In no event will the author be held                       }
{  liable for any damages arising from the use of this                         }
{  software.                                                                   }
{  Permission is granted to anyone to use this software for                    }
{  any purpose, including commercial applications, and to                      }
{  alter it and redistribute it freely, subject to the                         }
{  following restrictions:                                                     }
{  1. The origin of this software must not be misrepresented,                  }
{     you must not claim that you wrote the original software.                 }
{     If you use this software in a product, an acknowledgment                 }
{     in the product documentation would be appreciated but is                 }
{     not required.                                                            }
{  2. Altered source versions must be plainly marked as such,                  }
{     and must not be misrepresented as being the original                     }
{     software.                                                                }
{  3. This notice may not be removed or altered from any                       }
{     source distribution.                                                     }
{  4. You must credit the DFW team in  your software including a               }
{     link to the DFW homepage at http://www.delphifreeware.de.                }
{                                                                              }
{ End of license agreement                                                     }
{                                                                              }
{******************************************************************************}

{$I DFW.INC}

unit DFWMRUfiles;


interface

uses
  {$IFDEF WIN32} Windows {$ELSE} WinTypes, WinProcs {$ENDIF}, Classes, Menus;

const
      ComponentVersion='1.0';
      ComponentAuthor='Kambiz R. Khojasteh';
      ComponentEMail='khojasteh@www.dci.co.ir';
      ComponentHomePage='http://www.crosswinds.net/~khojasteh/';

type
  TMRUClickEvent = procedure(Sender: TObject; FileName: String) of object;
  TDFWMRUFiles = class(TComponent)
  private
    FFiles: TStringList;
    FMaxEntries: Byte;
    FMenu: TMenu;
    FItemsPos: Word;
    FNumbered: Boolean;
    MenuItemCount: Word;
    FOnClick: TMRUClickEvent;
    function GetVersion:string;
    function GetAuthor:string;
    function GetEMail:string;
    function GetHomepage:string;
    procedure SetMaxEntries(Value: Byte);
    procedure SetMenu(Value: TMenu);
    procedure SetItemsPos(Value: Word);
    procedure SetNumbered(Value: Boolean);
    procedure FilesChanged(Sender: TObject);
    procedure MenuItemClicked(Sender: TObject);
    procedure ClearMenuItems;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure Add(FileName: String);
    procedure Remove(FileName: String);
    procedure Rename(OldFileName, NewFileName: String);
    {$IFDEF WIN32}
    procedure LoadFromRegistry(Key: String);
    procedure SaveToRegistry(Key: String);
    {$ENDIF}
    procedure LoadFromIni(IniFileName, Section: String);
    procedure SaveToIni(IniFileName, Section: String);
    procedure LoadFromFile(FileName: String);
    procedure SaveToFile(FileName: String);
    property Files: TStringList read FFiles;
  published
    property Version: string read GetVersion;
    property Author: string read GetAuthor;
    property EMail: string read GetEMail;
    property Homepage: string read GetHomepage;
    property Menu: TMenu read FMenu write SetMenu;
    property ItemsPos: Word read FItemsPos write SetItemsPos default 0;
    property MaxEntries: Byte read FMaxEntries write SetMaxEntries default 9;
    property Numbered: Boolean read FNumbered write SetNumbered default True;
    property OnClick: TMRUClickEvent read FOnClick write FOnClick;
  end;


implementation

uses
  SysUtils, Forms, IniFiles {$IFDEF WIN32}, Registry {$ENDIF};

constructor TDFWMRUFiles.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FMenu := nil;
  FItemsPos := 0;
  FMaxEntries := 9;
  FNumbered := True;
  FFiles := TStringList.Create;
  Files.OnChange := FilesChanged;
end;

destructor TDFWMRUFiles.Destroy;
begin
  Files.Free;
  inherited Destroy;
end;

procedure TDFWMRUFiles.Add(FileName: String);
var
  I: Integer;
begin
  if FileName <> EmptyStr then
  begin
    Files.BeginUpdate;
    try
      for I := 0 to Files.Count-1 do
        if CompareText(Files[I], FileName) = 0 then
        begin
          Files.Delete(I);
          Break;
        end;
      while Files.Count >= MaxEntries do
        Files.Delete(MaxEntries-1);
      Files.Insert(0, FileName);
    finally
      Files.EndUpdate;
    end;
  end;
end;

procedure TDFWMRUFiles.Remove(FileName: String);
var
  I: integer;
begin
  if FileName <> EmptyStr then
    for I := 0 to Files.Count-1 do
      if (CompareText(Files[I], FileName) = 0) then
      begin
        Files.Delete(I);
        Break;
      end;
end;

procedure TDFWMRUFiles.Rename(OldFileName, NewFileName: String);
var
  I: integer;
begin
  if OldFileName <> NewFileName then
    if OldFileName = EmptyStr then
      Add(NewFileName)
    else if NewFileName = EmptyStr then
      Remove(OldFileName)
    else
      for I := 0 to Files.Count-1 do
        if (CompareText(Files[I], OldFileName) = 0) then
        begin
          Files[I] := NewFileName;
          Break;
        end;
end;

{$IFDEF WIN32}

procedure TDFWMRUFiles.LoadFromRegistry(Key: String);
var
  I: Integer;
  FileName: String;
  Registry: TRegistry;
begin
  Files.BeginUpdate;
  Files.Clear;
  Registry := TRegistry.Create;
  try
    Registry.RootKey := HKEY_CURRENT_USER;
{$IFDEF D2}
    if Registry.OpenKey(Key, False) then
{$ELSE}
    if Registry.OpenKeyReadOnly(Key) then
{$ENDIF}
    begin
      for I := 1 to MaxEntries do
      begin
        if Registry.ValueExists(Format('File%d', [I])) then
        begin
          FileName := Registry.ReadString(Format('File%d', [I]));
          if (FileName <> EmptyStr) and (Files.IndexOf(FileName) < 0) then
            Files.Add(FileName);
        end;
      end;
      Registry.CloseKey;
    end;
  finally
    Registry.Free;
    Files.EndUpdate;
  end;
end;

procedure TDFWMRUFiles.SaveToRegistry(Key: String);
var
  I: Integer;
  Registry: TRegistry;
begin
  Registry := TRegistry.Create;
  try
    Registry.RootKey := HKEY_CURRENT_USER;
    Registry.DeleteKey(Key);
    if Registry.OpenKey(Key, True) then
    begin
      for I := 1 to Files.Count do
        Registry.WriteString(Format('File%d', [I]), Files[I-1]);
      Registry.CloseKey;
    end;
  finally
    Registry.Free;
  end;
end;

{$ENDIF}

procedure TDFWMRUFiles.LoadFromIni(IniFileName, Section: String);
var
  I: Integer;
  FileName: String;
  Ini: TIniFile;
begin
  Files.BeginUpdate;
  Files.Clear;
  Ini := TIniFile.Create(IniFileName);
  try
    for I := 1 to MaxEntries do
    begin
      FileName := Ini.ReadString(Section, Format('File%d', [I]), EmptyStr);
      if FileName = EmptyStr then
        Break
      else if Files.IndexOf(FileName) < 0 then
        Files.Add(FileName);
    end;
  finally
    Ini.Free;
    Files.EndUpdate;
  end;
end;

procedure TDFWMRUFiles.SaveToIni(IniFileName, Section: String);
var
  I: Integer;
  Ini: TIniFile;
begin
  Ini := TIniFile.Create(IniFileName);
  try
    Ini.EraseSection(Section);
    for I := 1 to Files.Count do
      Ini.WriteString(Section, Format('File%d', [I]), Files[I-1]);
  finally
    Ini.Free;
  end;
end;

procedure TDFWMRUFiles.LoadFromFile(FileName: String);
begin
  Files.BeginUpdate;
  Files.Clear;
  try
    Files.LoadFromFile(FileName);
  finally
    Files.EndUpdate;
  end;
end;

procedure TDFWMRUFiles.SaveToFile(FileName: String);
begin
  Files.SaveToFile(FileName);
end;

procedure TDFWMRUFiles.SetMaxEntries(Value: Byte);
begin
  if MaxEntries <> Value then
  begin
    FMaxEntries := Value;
    Files.BeginUpdate;
    try
      while Files.Count >= MaxEntries do
        Files.Delete(MaxEntries-1);
    finally
      Files.EndUpdate;
    end;
  end;
end;

procedure TDFWMRUFiles.SetNumbered(Value: Boolean);
begin
  if Numbered <> Value then
  begin
    FNumbered := Value;
    FilesChanged(Self);
  end;
end;

procedure TDFWMRUFiles.SetItemsPos(Value: Word);
begin
  if not (csLoading in ComponentState) then
    if Menu = nil then
      Value := 0
    else if (Value <> 0) and (Value >= Menu.Items.Count) then
      Value := Menu.Items.Count-1;
  if ItemsPos <> Value then
  begin
    ClearMenuItems;
    FItemsPos := Value;
    FilesChanged(Self);
  end;
end;

procedure TDFWMRUFiles.SetMenu(Value: TMenu);
begin
  if Menu <> Value then
  begin
    ClearMenuItems;
    FMenu := Value;
    if (Menu <> nil) and (ItemsPos <> 0) and (ItemsPos >= Menu.Items.Count) then
      FItemsPos := Menu.Items.Count-1;
    FilesChanged(Self);
  end;
end;

procedure TDFWMRUFiles.ClearMenuItems;
var
  I: Integer;
begin
  if Menu <> nil then
  begin
    for I := 1 to MenuItemCount do
      Menu.Items.Delete(ItemsPos);
    MenuItemCount := 0;
  end;
end;

procedure TDFWMRUFiles.FilesChanged(Sender: TObject);
var
  I: Integer;
  MenuItem: TMenuItem;
begin
  if Menu <> nil then
  begin
    ClearMenuItems;
    for I := Files.Count-1 downto 0 do
    begin
      MenuItem := TMenuItem.Create(Self);
      MenuItem.Tag := I;
      MenuItem.Hint := Format('Opens %s', [Files[I]]);
      if not Numbered then
        MenuItem.Caption := Format('%s', [Files[I]])
      else if I < 10 then
        MenuItem.Caption := Format('&%d %s', [I+1, Files[I]])
      else
        MenuItem.Caption := Format('  %s', [Files[I]]);
      MenuItem.OnClick := MenuItemClicked;
      Menu.Items.Insert(ItemsPos, MenuItem);
      Inc(MenuItemCount);
    end;
    if (ItemsPos > 0) and (Files.Count > 0) then
    begin
      MenuItem := TMenuItem.Create(Self);
      MenuItem.Caption := '-';
      Menu.Items.Insert(ItemsPos, MenuItem);
      Inc(MenuItemCount);
    end;
  end;
end;

procedure TDFWMRUFiles.MenuItemClicked(Sender: TObject);
begin
  if Assigned(FOnClick) and (Sender is TMenuItem) then
    FOnClick(Self, Files[TMenuItem(Sender).Tag]);
end;

function TDFWMRUFiles.GetVersion:string;
begin
     Result:=ComponentVersion;
end;

function TDFWMRUFiles.GetAuthor:string;
begin
     Result:=ComponentAuthor;
end;

function TDFWMRUFiles.GetEMail:string;
begin
     Result:=ComponentEMail;
end;

function TDFWMRUFiles.GetHomepage:string;
begin
     Result:=ComponentHomePage;
end;
end.
