{******************************************************************************}
{          This unit is part of the Delphifreeware component package.          }
{                                                                              }
{ Filename           : DFWMemoes.pas                                           }
{ Short description  : TMemo with additional gap                               }
{ Author             : Erol S. Uzuner                                          }
{ E-Mail             : sarcon@tzi.de                                           }
{ Internet           :                                                         }
{ Version            : 1.0                                                     }
{ Date last modified : 26.08.97                                                }
{ Delphi versions    :                                                         }
{                                                                              }
{                                                                              }
{ Add. Copyright     : Copyright (C) 1996-2000                                 }
{                                                                              }
{ Description        :                                                         }
{                                                                              }
{ Usage              :                                                         }
{                                                                              }
{ Revision history   : 26.08.97 Initial release                                }
{                                                                              }
{ This unit contains the following                                             }
{ Components       : TDFWMemoes                                                }
{ Classes          :                                                           }
{ Types            :                                                           }
{ Constants        :                                                           }
{ Global variables :                                                           }
{ Global procedures:                                                           }
{ Global functions :                                                           }
{                                                                              }
{******************************************************************************}
{                                                                              }
{  DFW and Delphifreeware   2000, Carsten Butzek E-Mail: cabutzek@muenster.de }
{                                                                              }
{  Delphifreeware or DFW is a free Delphi component collection.                }
{  If you wrote a component which should be integrated into the DFW please     }
{  contact me.                                                                 }
{                                                                              }
{  Updates of the DFW package are available at the DFW homepage:               }
{  http://www.delphifreeware.de                                                }
{                                                                              }
{******************************************************************************}
{ License agreement                                                            }
{                                                                              }
{  This unit is freeware.                                                      }
{                                                                              }
{  Please do not release modified versions of this source code.                }
{  If you've made any changes that you think should have been there,           }
{  feel free to submit them to me at cabutzek@muenster.de                      }
{                                                                              }
{                                                                              }
{  This software is provided 'as-is', without any express or                   }
{  implied warranty. In no event will the author be held                       }
{  liable for any damages arising from the use of this                         }
{  software.                                                                   }
{  Permission is granted to anyone to use this software for                    }
{  any purpose, including commercial applications, and to                      }
{  alter it and redistribute it freely, subject to the                         }
{  following restrictions:                                                     }
{  1. The origin of this software must not be misrepresented,                  }
{     you must not claim that you wrote the original software.                 }
{     If you use this software in a product, an acknowledgment                 }
{     in the product documentation would be appreciated but is                 }
{     not required.                                                            }
{  2. Altered source versions must be plainly marked as such,                  }
{     and must not be misrepresented as being the original                     }
{     software.                                                                }
{  3. This notice may not be removed or altered from any                       }
{     source distribution.                                                     }
{  4. You must credit the DFW team in  your software including a               }
{     link to the DFW homepage at http://www.delphifreeware.de.                }
{                                                                              }
{ End of license agreement                                                     }
{                                                                              }
{******************************************************************************}

{$I DFW.INC}

unit DFWMemoes;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

const
      ComponentVersion='1.0';
      ComponentAuthor='Erol S. Uzuner';
      ComponentEMail='sarcon@tzi.de';
      ComponentHomePage='';

type
  TDFWMemoes = class(TMemo)
  private
    { Private-Deklarationen }
    FTopGap, FLeftGap, FRightGap, FBottomGap : Integer;
    procedure SetEditRect;
    procedure WMWindowPosChanged(var Message: TWMWindowPosChanged); message WM_WINDOWPOSCHANGED;
  protected
    { Protected-Deklarationen }
    procedure CreateWnd; override;
    procedure CreateParams(var Params: TCreateParams); override;

    procedure setLeftGap(value : Integer);
    procedure setTopGap(value : Integer);
    procedure setRightGap(value : Integer);
    procedure setBottomGap(value : Integer);
    function GetVersion:string;
    function GetAuthor:string;
    function GetEMail:string;
    function GetHomepage:string;
  public
    { Public-Deklarationen }
    constructor Create(AOwner : TComponent);override;
    destructor Destroy; override;
  published
    { Published-Deklarationen }
      property Version: string read GetVersion;
      property Author: string read GetAuthor;
      property EMail: string read GetEMail;
      property Homepage: string read GetHomepage;
      property GapLeft : Integer read FLeftGap write setLeftGap default 0;
      property GapTop : Integer read FTopGap write setTopGap default 0;
      property GapRight : Integer read FRightGap write setRightGap default 0;
      property GapBottom : Integer read FBottomGap write setBottomGap default 0;
  end;

implementation

constructor TDFWMemoes.Create(AOwner : TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := ControlStyle + [csAcceptsControls];
  FLeftGap := 0;
  FTopGap := 0;
  FRightGap := 0;
  FBottomGap := 0;
end;

destructor TDFWMemoes.Destroy;
begin

  inherited Destroy;
end;

procedure TDFWMemoes.WMWindowPosChanged(var Message: TWMWindowPosChanged);
begin
  inherited;
  SetEditRect;
end;

procedure TDFWMemoes.CreateWnd;
begin
  inherited CreateWnd;
  SetEditRect;
end;

procedure TDFWMemoes.CreateParams(var Params: TCreateParams);
begin
  inherited CreateParams(Params);
  Params.Style := Params.Style or WS_CLIPCHILDREN;
end;

procedure TDFWMemoes.SetEditRect;
var
  Loc: TRect;
begin
  SetRect(Loc, FLeftGap, FTopGap, (ClientWidth -1) -FRightGap, (ClientHeight + 1) - FBottomGap);
  SendMessage(Handle, EM_SETRECTNP, 0, LongInt(@Loc));
end;


procedure TDFWMemoes.setLeftGap(value : Integer);
begin
 if (FLeftGap <> value) AND (value > -1) then begin
   FLeftGap := value;
   ReCreateWnd;
 end;
end;

procedure TDFWMemoes.setTopGap(value : Integer);
begin
  if (FTopGap <> value) AND (value > -1) then begin
   FTopGap := value;
   ReCreateWnd;
 end;
end;

procedure TDFWMemoes.setRightGap(value : Integer);
begin
 if (FRightGap <> value) AND (value > -1) then begin
   FRightGap := value;
   ReCreateWnd;
 end;
end;

procedure TDFWMemoes.setBottomGap(value : Integer);
begin
 if (FBottomGap <> value) AND (value > -1) then begin
   FBottomGap := value;
   ReCreateWnd;
 end;
end;

function TDFWMemoes.GetVersion:string;
begin
     Result:=ComponentVersion;
end;

function TDFWMemoes.GetAuthor:string;
begin
     Result:=ComponentAuthor;
end;

function TDFWMemoes.GetEMail:string;
begin
     Result:=ComponentEMail;
end;

function TDFWMemoes.GetHomepage:string;
begin
     Result:=ComponentHomePage;
end;

end.
